@@ -1,6 +1,6 @@
 /*
   SDL_mixer:  An audio mixer library based on the SDL library
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -96,14 +96,14 @@ static int reserved_channels = 0;
 
 
 /* Support for hooking into the mixer callback system */
-static void (SDLCALL *mix_postmix)(void *udata, Uint8 *stream, int len) = NULL;
+static Mix_MixCallback mix_postmix = NULL;
 static void *mix_postmix_data = NULL;
 
 /* rcg07062001 callback to alert when channels are done playing. */
-static void (SDLCALL *channel_done_callback)(int channel) = NULL;
+static Mix_ChannelFinishedCallback channel_done_callback = NULL;
 
 /* Support for user defined music functions */
-static void (SDLCALL *mix_music)(void *udata, Uint8 *stream, int len) = music_mixer;
+static Mix_MixCallback mix_music = music_mixer;
 static void *music_data = NULL;
 
 /* rcg06042009 report available decoders at runtime. */
@@ -114,7 +114,7 @@ static SDL_atomic_t master_volume = { MIX_MAX_VOLUME };
 
 int Mix_GetNumChunkDecoders(void)
 {
-    return(num_decoders);
+    return num_decoders;
 }
 
 const char *Mix_GetChunkDecoder(int index)
@@ -122,7 +122,7 @@ const char *Mix_GetChunkDecoder(int index)
     if ((index < 0) || (index >= num_decoders)) {
         return NULL;
     }
-    return(chunk_decoders[index]);
+    return chunk_decoders[index];
 }
 
 SDL_bool Mix_HasChunkDecoder(const char *name)
@@ -148,7 +148,7 @@ void add_chunk_decoder(const char *decoder)
         }
     }
 
-    ptr = SDL_realloc((void *)chunk_decoders, (size_t)(num_decoders + 1) * sizeof (const char *));
+    ptr = SDL_realloc((void *)chunk_decoders, (size_t)(num_decoders + 1) * sizeof(const char *));
     if (ptr == NULL) {
         return;  /* oh well, go on without it. */
     }
@@ -161,7 +161,7 @@ const SDL_version *Mix_Linked_Version(void)
 {
     static SDL_version linked_version;
     SDL_MIXER_VERSION(&linked_version);
-    return(&linked_version);
+    return &linked_version;
 }
 
 /*
@@ -185,6 +185,9 @@ static int get_loaded_mix_init_flags(void)
             case MUS_FLAC:
                 loaded_init_flags |= MIX_INIT_FLAC;
                 break;
+            case MUS_WAVPACK:
+                loaded_init_flags |= MIX_INIT_WAVPACK;
+                break;
             case MUS_MOD:
                 loaded_init_flags |= MIX_INIT_MOD;
                 break;
@@ -222,6 +225,14 @@ int Mix_Init(int flags)
             Mix_SetError("FLAC support not available");
         }
     }
+    if (flags & MIX_INIT_WAVPACK) {
+        if (load_music_type(MUS_WAVPACK)) {
+            open_music_type(MUS_WAVPACK);
+            result |= MIX_INIT_WAVPACK;
+        } else {
+            Mix_SetError("WavPack support not available");
+        }
+    }
     if (flags & MIX_INIT_MOD) {
         if (load_music_type(MUS_MOD)) {
             open_music_type(MUS_MOD);
@@ -304,7 +315,7 @@ static void *Mix_DoEffects(int chan, void *snd, int len)
         if (!posteffect) {
             buf = SDL_malloc((size_t)len);
             if (buf == NULL) {
-                return(snd);
+                return snd;
             }
             SDL_memcpy(buf, snd, (size_t)len);
         }
@@ -317,7 +328,7 @@ static void *Mix_DoEffects(int chan, void *snd, int len)
     }
 
     /* be sure to SDL_free() the return value if != snd ... */
-    return(buf);
+    return buf;
 }
 
 
@@ -341,7 +352,7 @@ mix_channels(void *udata, Uint8 *stream, int len)
 
     /* Mix any playing channels... */
     sdl_ticks = SDL_GetTicks();
-    for (i=0; i<num_channels; ++i) {
+    for (i = 0; i < num_channels; ++i) {
         if (!mix_channel[i].paused) {
             if (mix_channel[i].expire > 0 && mix_channel[i].expire < sdl_ticks) {
                 /* Expiration delay for that channel is reached */
@@ -392,6 +403,8 @@ mix_channels(void *udata, Uint8 *stream, int len)
 
                     /* rcg06072001 Alert app if channel is done playing. */
                     if (!mix_channel[i].playing && !mix_channel[i].looping) {
+                        mix_channel[i].fading = MIX_NO_FADING;
+                        mix_channel[i].expire = 0;
                         _Mix_channel_done_playing(i);
 
                         /* Update the volume after the application callback */
@@ -469,7 +482,7 @@ int Mix_OpenAudioDevice(int frequency, Uint16 format, int nchannels, int chunksi
     if (audio_opened) {
         if (format == mixer.format && nchannels == mixer.channels) {
             ++audio_opened;
-            return(0);
+            return 0;
         }
         while (audio_opened) {
             Mix_CloseAudio();
@@ -486,7 +499,7 @@ int Mix_OpenAudioDevice(int frequency, Uint16 format, int nchannels, int chunksi
 
     /* Accept nearly any audio format */
     if ((audio_device = SDL_OpenAudioDevice(device, 0, &desired, &mixer, allowed_changes)) == 0) {
-        return(-1);
+        return -1;
     }
 #if 0
     PrintFormat("Audio device", &mixer);
@@ -496,7 +509,7 @@ int Mix_OpenAudioDevice(int frequency, Uint16 format, int nchannels, int chunksi
     mix_channel = (struct _Mix_Channel *) SDL_malloc(num_channels * sizeof(struct _Mix_Channel));
 
     /* Clear out the audio channels */
-    for (i=0; i<num_channels; ++i) {
+    for (i = 0; i < num_channels; ++i) {
         mix_channel[i].chunk = NULL;
         mix_channel[i].playing = 0;
         mix_channel[i].looping = 0;
@@ -522,7 +535,7 @@ int Mix_OpenAudioDevice(int frequency, Uint16 format, int nchannels, int chunksi
 
     audio_opened = 1;
     SDL_PauseAudioDevice(audio_device, 0);
-    return(0);
+    return 0;
 }
 
 /* Open the mixer with a certain desired audio format */
@@ -533,45 +546,71 @@ int Mix_OpenAudio(int frequency, Uint16 format, int nchannels, int chunksize)
                                 SDL_AUDIO_ALLOW_CHANNELS_CHANGE);
 }
 
+/* Pause or resume the audio streaming */
+void Mix_PauseAudio(int pause_on)
+{
+    SDL_PauseAudioDevice(audio_device, pause_on);
+    Mix_LockAudio();
+    pause_async_music(pause_on);
+    Mix_UnlockAudio();
+}
+
 /* Dynamically change the number of channels managed by the mixer.
    If decreasing the number of channels, the upper channels are
    stopped.
  */
 int Mix_AllocateChannels(int numchans)
 {
+    struct _Mix_Channel *mix_channel_tmp;
+
     if (numchans<0 || numchans==num_channels)
-        return(num_channels);
+        return num_channels;
 
     if (numchans < num_channels) {
         /* Stop the affected channels */
         int i;
-        for(i=numchans; i < num_channels; i++) {
+        for (i = numchans; i < num_channels; i++) {
             Mix_UnregisterAllEffects(i);
             Mix_HaltChannel(i);
         }
     }
     Mix_LockAudio();
-    mix_channel = (struct _Mix_Channel *) SDL_realloc(mix_channel, numchans * sizeof(struct _Mix_Channel));
-    if (numchans > num_channels) {
-        /* Initialize the new channels */
-        int i;
-        for(i=num_channels; i < numchans; i++) {
-            mix_channel[i].chunk = NULL;
-            mix_channel[i].playing = 0;
-            mix_channel[i].looping = 0;
-            mix_channel[i].volume = MIX_MAX_VOLUME;
-            mix_channel[i].fade_volume = MIX_MAX_VOLUME;
-            mix_channel[i].fade_volume_reset = MIX_MAX_VOLUME;
-            mix_channel[i].fading = MIX_NO_FADING;
-            mix_channel[i].tag = -1;
-            mix_channel[i].expire = 0;
-            mix_channel[i].effects = NULL;
-            mix_channel[i].paused = 0;
+    /* Allocate channels into temporary pointer */
+    if (numchans) {
+        mix_channel_tmp = (struct _Mix_Channel *) SDL_realloc(mix_channel, numchans * sizeof(struct _Mix_Channel));
+    } else {
+        /* Handle 0 numchans */
+        SDL_free(mix_channel);
+        mix_channel_tmp = NULL;
+    }
+    /* Check the allocation */
+    if (mix_channel_tmp || !numchans) {
+        /* Apply the temporary pointer on success */
+        mix_channel = mix_channel_tmp;
+        if (numchans > num_channels) {
+            /* Initialize the new channels */
+            int i;
+            for (i = num_channels; i < numchans; i++) {
+                mix_channel[i].chunk = NULL;
+                mix_channel[i].playing = 0;
+                mix_channel[i].looping = 0;
+                mix_channel[i].volume = MIX_MAX_VOLUME;
+                mix_channel[i].fade_volume = MIX_MAX_VOLUME;
+                mix_channel[i].fade_volume_reset = MIX_MAX_VOLUME;
+                mix_channel[i].fading = MIX_NO_FADING;
+                mix_channel[i].tag = -1;
+                mix_channel[i].expire = 0;
+                mix_channel[i].effects = NULL;
+                mix_channel[i].paused = 0;
+            }
         }
+        num_channels = numchans;
+    } else {
+        /* On error mix_channel remains intact */
+        Mix_SetError("Channel allocation failed");
     }
-    num_channels = numchans;
     Mix_UnlockAudio();
-    return(num_channels);
+    return num_channels; /* If the return value equals numchans the allocation was successful */
 }
 
 /* Return the actual mixer parameters */
@@ -588,7 +627,7 @@ int Mix_QuerySpec(int *frequency, Uint16 *format, int *channels)
             *channels = mixer.channels;
         }
     }
-    return(audio_opened);
+    return audio_opened;
 }
 
 typedef struct _MusicFragment
@@ -748,11 +787,13 @@ Mix_Chunk *Mix_LoadWAV_RW(SDL_RWops *src, int freesrc)
     SDL_AudioSpec wavespec, *loaded;
     SDL_AudioCVT wavecvt;
     int samplesize;
+    int wavfree;        /* to decide how to free chunk->abuf. */
+    Uint8 *resized_buf;
 
     /* rcg06012001 Make sure src is valid */
     if (!src) {
         Mix_SetError("Mix_LoadWAV_RW with NULL src");
-        return(NULL);
+        return NULL;
     }
 
     /* Make sure audio has been opened */
@@ -761,7 +802,7 @@ Mix_Chunk *Mix_LoadWAV_RW(SDL_RWops *src, int freesrc)
         if (freesrc) {
             SDL_RWclose(src);
         }
-        return(NULL);
+        return NULL;
     }
 
     /* Allocate the chunk memory */
@@ -771,7 +812,7 @@ Mix_Chunk *Mix_LoadWAV_RW(SDL_RWops *src, int freesrc)
         if (freesrc) {
             SDL_RWclose(src);
         }
-        return(NULL);
+        return NULL;
     }
 
     /* Find out what kind of audio file this is */
@@ -786,7 +827,9 @@ Mix_Chunk *Mix_LoadWAV_RW(SDL_RWops *src, int freesrc)
     /* Seek backwards for compatibility with older loaders */
     SDL_RWseek(src, -4, RW_SEEK_CUR);
 
+    wavfree = 0;
     if (SDL_memcmp(magic, "WAVE", 4) == 0 || SDL_memcmp(magic, "RIFF", 4) == 0) {
+        wavfree = 1;
         loaded = SDL_LoadWAV_RW(src, freesrc, &wavespec, (Uint8 **)&chunk->abuf, &chunk->alen);
     } else if (SDL_memcmp(magic, "FORM", 4) == 0) {
         loaded = Mix_LoadAIFF_RW(src, freesrc, &wavespec, (Uint8 **)&chunk->abuf, &chunk->alen);
@@ -798,7 +841,7 @@ Mix_Chunk *Mix_LoadWAV_RW(SDL_RWops *src, int freesrc)
     if (!loaded) {
         /* The individual loaders have closed src if needed */
         SDL_free(chunk);
-        return(NULL);
+        return NULL;
     }
 
 #if 0
@@ -813,37 +856,55 @@ Mix_Chunk *Mix_LoadWAV_RW(SDL_RWops *src, int freesrc)
         if (SDL_BuildAudioCVT(&wavecvt,
                 wavespec.format, wavespec.channels, wavespec.freq,
                 mixer.format, mixer.channels, mixer.freq) < 0) {
-            SDL_free(chunk->abuf);
+            if (wavfree) {
+                SDL_FreeWAV(chunk->abuf);
+            } else {
+                SDL_free(chunk->abuf);
+            }
             SDL_free(chunk);
-            return(NULL);
+            return NULL;
         }
         samplesize = ((wavespec.format & 0xFF)/8)*wavespec.channels;
-        wavecvt.len = chunk->alen & ~(samplesize-1);
+        wavecvt.len = chunk->alen & ~(samplesize - 1);
         wavecvt.buf = (Uint8 *)SDL_calloc(1, wavecvt.len*wavecvt.len_mult);
         if (wavecvt.buf == NULL) {
             Mix_OutOfMemory();
-            SDL_free(chunk->abuf);
+            if (wavfree) {
+                SDL_FreeWAV(chunk->abuf);
+            } else {
+                SDL_free(chunk->abuf);
+            }
             SDL_free(chunk);
-            return(NULL);
+            return NULL;
         }
         SDL_memcpy(wavecvt.buf, chunk->abuf, wavecvt.len);
-        SDL_free(chunk->abuf);
+        if (wavfree) {
+            SDL_FreeWAV(chunk->abuf);
+        } else {
+            SDL_free(chunk->abuf);
+        }
 
         /* Run the audio converter */
         if (SDL_ConvertAudio(&wavecvt) < 0) {
             SDL_free(wavecvt.buf);
             SDL_free(chunk);
-            return(NULL);
+            return NULL;
         }
 
-        chunk->abuf = wavecvt.buf;
+        resized_buf = SDL_realloc(wavecvt.buf, wavecvt.len_cvt);
+        if (resized_buf == NULL) {
+            chunk->abuf = wavecvt.buf;
+        } else {
+            chunk->abuf = resized_buf;
+        }
         chunk->alen = wavecvt.len_cvt;
+        wavfree = 0;
     }
 
-    chunk->allocated = 1;
+    chunk->allocated = (wavfree == 0) ? 1 : 2; /* see Mix_FreeChunk() */
     chunk->volume = MIX_MAX_VOLUME;
 
-    return(chunk);
+    return chunk;
 }
 
 Mix_Chunk *Mix_LoadWAV(const char *file)
@@ -861,14 +922,14 @@ Mix_Chunk *Mix_QuickLoad_WAV(Uint8 *mem)
     /* Make sure audio has been opened */
     if (! audio_opened) {
         Mix_SetError("Audio device hasn't been opened");
-        return(NULL);
+        return NULL;
     }
 
     /* Allocate the chunk memory */
     chunk = (Mix_Chunk *)SDL_calloc(1,sizeof(Mix_Chunk));
     if (chunk == NULL) {
         Mix_OutOfMemory();
-        return(NULL);
+        return NULL;
     }
 
     /* Essentially just skip to the audio data (no error checking - fast) */
@@ -884,7 +945,7 @@ Mix_Chunk *Mix_QuickLoad_WAV(Uint8 *mem)
     } while (SDL_memcmp(magic, "data", 4) != 0);
     chunk->volume = MIX_MAX_VOLUME;
 
-    return(chunk);
+    return chunk;
 }
 
 /* Load raw audio data of the mixer format from a memory buffer */
@@ -895,14 +956,14 @@ Mix_Chunk *Mix_QuickLoad_RAW(Uint8 *mem, Uint32 len)
     /* Make sure audio has been opened */
     if (! audio_opened) {
         Mix_SetError("Audio device hasn't been opened");
-        return(NULL);
+        return NULL;
     }
 
     /* Allocate the chunk memory */
     chunk = (Mix_Chunk *)SDL_malloc(sizeof(Mix_Chunk));
     if (chunk == NULL) {
         Mix_OutOfMemory();
-        return(NULL);
+        return NULL;
     }
 
     /* Essentially just point at the audio data (no error checking - fast) */
@@ -911,16 +972,16 @@ Mix_Chunk *Mix_QuickLoad_RAW(Uint8 *mem, Uint32 len)
     chunk->abuf = mem;
     chunk->volume = MIX_MAX_VOLUME;
 
-    return(chunk);
+    return chunk;
 }
 
 /* MAKE SURE you hold the audio lock (Mix_LockAudio()) before calling this! */
 static void  Mix_HaltChannel_locked(int which)
 {
     if (Mix_Playing(which)) {
-        _Mix_channel_done_playing(which);
         mix_channel[which].playing = 0;
         mix_channel[which].looping = 0;
+        _Mix_channel_done_playing(which);
     }
     mix_channel[which].expire = 0;
     if (mix_channel[which].fading != MIX_NO_FADING) /* Restore volume */
@@ -938,7 +999,7 @@ void Mix_FreeChunk(Mix_Chunk *chunk)
         /* Guarantee that this chunk isn't playing */
         Mix_LockAudio();
         if (mix_channel) {
-            for (i=0; i<num_channels; ++i) {
+            for (i = 0; i < num_channels; ++i) {
                 if (chunk == mix_channel[i].chunk) {
                     Mix_HaltChannel_locked(i);
                 }
@@ -946,8 +1007,13 @@ void Mix_FreeChunk(Mix_Chunk *chunk)
         }
         Mix_UnlockAudio();
         /* Actually free the chunk */
-        if (chunk->allocated) {
+        switch (chunk->allocated) {
+        case 1:
             SDL_free(chunk->abuf);
+            break;
+        case 2:
+            SDL_FreeWAV(chunk->abuf);
+            break;
         }
         SDL_free(chunk);
     }
@@ -957,8 +1023,7 @@ void Mix_FreeChunk(Mix_Chunk *chunk)
    This can be used to provide real-time visual display of the audio stream
    or add a custom mixer filter for the stream data.
 */
-void Mix_SetPostMix(void (SDLCALL *mix_func)
-                    (void *udata, Uint8 *stream, int len), void *arg)
+void Mix_SetPostMix(Mix_MixCallback mix_func, void *arg)
 {
     Mix_LockAudio();
     mix_postmix_data = arg;
@@ -969,8 +1034,7 @@ void Mix_SetPostMix(void (SDLCALL *mix_func)
 /* Add your own music player or mixer function.
    If 'mix_func' is NULL, the default music player is re-enabled.
  */
-void Mix_HookMusic(void (SDLCALL *mix_func)(void *udata, Uint8 *stream, int len),
-                                                                void *arg)
+void Mix_HookMusic(Mix_MixCallback mix_func, void *arg)
 {
     Mix_LockAudio();
     if (mix_func != NULL) {
@@ -985,10 +1049,10 @@ void Mix_HookMusic(void (SDLCALL *mix_func)(void *udata, Uint8 *stream, int len)
 
 void *Mix_GetMusicHookData(void)
 {
-    return(music_data);
+    return music_data;
 }
 
-void Mix_ChannelFinished(void (SDLCALL *channel_finished)(int channel))
+void Mix_ChannelFinished(Mix_ChannelFinishedCallback channel_finished)
 {
     Mix_LockAudio();
     channel_done_callback = channel_finished;
@@ -1002,6 +1066,8 @@ void Mix_ChannelFinished(void (SDLCALL *channel_finished)(int channel))
  */
 int Mix_ReserveChannels(int num)
 {
+    if (num < 0)
+        num = 0;
     if (num > num_channels)
         num = num_channels;
     reserved_channels = num;
@@ -1030,12 +1096,10 @@ int Mix_PlayChannelTimed(int which, Mix_Chunk *chunk, int loops, int ticks)
 
     /* Don't play null pointers :-) */
     if (chunk == NULL) {
-        Mix_SetError("Tried to play a NULL chunk");
-        return(-1);
+        return Mix_SetError("Tried to play a NULL chunk");
     }
     if (!checkchunkintegral(chunk)) {
-        Mix_SetError("Tried to play a chunk with a bad frame");
-        return(-1);
+        return Mix_SetError("Tried to play a chunk with a bad frame");
     }
 
     /* Lock the mixer while modifying the playing channels */
@@ -1043,7 +1107,7 @@ int Mix_PlayChannelTimed(int which, Mix_Chunk *chunk, int loops, int ticks)
     {
         /* If which is -1, play on the first free channel */
         if (which == -1) {
-            for (i=reserved_channels; i<num_channels; ++i) {
+            for (i = reserved_channels; i < num_channels; ++i) {
                 if (!Mix_Playing(i))
                     break;
             }
@@ -1074,7 +1138,7 @@ int Mix_PlayChannelTimed(int which, Mix_Chunk *chunk, int loops, int ticks)
     Mix_UnlockAudio();
 
     /* Return the channel on which the sound is being played */
-    return(which);
+    return which;
 }
 
 int Mix_PlayChannel(int channel, Mix_Chunk *chunk, int loops)
@@ -1089,16 +1153,16 @@ int Mix_ExpireChannel(int which, int ticks)
 
     if (which == -1) {
         int i;
-        for (i=0; i < num_channels; ++ i) {
+        for (i = 0; i < num_channels; ++i) {
             status += Mix_ExpireChannel(i, ticks);
         }
     } else if (which < num_channels) {
         Mix_LockAudio();
         mix_channel[which].expire = (ticks>0) ? (SDL_GetTicks() + (Uint32)ticks) : 0;
         Mix_UnlockAudio();
-        ++ status;
+        ++status;
     }
-    return(status);
+    return status;
 }
 
 /* Fade in a sound on a channel, over ms milliseconds */
@@ -1108,11 +1172,10 @@ int Mix_FadeInChannelTimed(int which, Mix_Chunk *chunk, int loops, int ms, int t
 
     /* Don't play null pointers :-) */
     if (chunk == NULL) {
-        return(-1);
+        return -1;
     }
     if (!checkchunkintegral(chunk)) {
-        Mix_SetError("Tried to play a chunk with a bad frame");
-        return(-1);
+        return Mix_SetError("Tried to play a chunk with a bad frame");
     }
 
     /* Lock the mixer while modifying the playing channels */
@@ -1120,7 +1183,7 @@ int Mix_FadeInChannelTimed(int which, Mix_Chunk *chunk, int loops, int ms, int t
     {
         /* If which is -1, play on the first free channel */
         if (which == -1) {
-            for (i=reserved_channels; i<num_channels; ++i) {
+            for (i = reserved_channels; i < num_channels; ++i) {
                 if (!Mix_Playing(i))
                     break;
             }
@@ -1156,7 +1219,7 @@ int Mix_FadeInChannelTimed(int which, Mix_Chunk *chunk, int loops, int ms, int t
     Mix_UnlockAudio();
 
     /* Return the channel on which the sound is being played */
-    return(which);
+    return which;
 }
 
 int Mix_FadeInChannel(int channel, Mix_Chunk *chunk, int loops, int ms)
@@ -1172,7 +1235,7 @@ int Mix_Volume(int which, int volume)
     int prev_volume = 0;
 
     if (which == -1) {
-        for (i=0; i<num_channels; ++i) {
+        for (i = 0; i < num_channels; ++i) {
             prev_volume += Mix_Volume(i, volume);
         }
         prev_volume /= num_channels;
@@ -1185,7 +1248,7 @@ int Mix_Volume(int which, int volume)
             mix_channel[which].volume = volume;
         }
     }
-    return(prev_volume);
+    return prev_volume;
 }
 /* Set volume of a particular chunk */
 int Mix_VolumeChunk(Mix_Chunk *chunk, int volume)
@@ -1193,7 +1256,7 @@ int Mix_VolumeChunk(Mix_Chunk *chunk, int volume)
     int prev_volume;
 
     if (chunk == NULL) {
-        return(-1);
+        return -1;
     }
     prev_volume = chunk->volume;
     if (volume >= 0) {
@@ -1202,7 +1265,7 @@ int Mix_VolumeChunk(Mix_Chunk *chunk, int volume)
         }
         chunk->volume = volume;
     }
-    return(prev_volume);
+    return prev_volume;
 }
 
 /* Halt playing of a particular channel */
@@ -1212,14 +1275,14 @@ int Mix_HaltChannel(int which)
 
     Mix_LockAudio();
     if (which == -1) {
-        for (i=0; i<num_channels; ++i) {
+        for (i = 0; i < num_channels; ++i) {
             Mix_HaltChannel_locked(i);
         }
     } else if (which < num_channels) {
         Mix_HaltChannel_locked(which);
     }
     Mix_UnlockAudio();
-    return(0);
+    return 0;
 }
 
 /* Halt playing of a particular group of channels */
@@ -1227,12 +1290,12 @@ int Mix_HaltGroup(int tag)
 {
     int i;
 
-    for (i=0; i<num_channels; ++i) {
+    for (i = 0; i < num_channels; ++i) {
         if (mix_channel[i].tag == tag) {
             Mix_HaltChannel(i);
         }
     }
-    return(0);
+    return 0;
 }
 
 /* Fade out a channel and then stop it automatically */
@@ -1245,7 +1308,7 @@ int Mix_FadeOutChannel(int which, int ms)
         if (which == -1) {
             int i;
 
-            for (i=0; i<num_channels; ++i) {
+            for (i = 0; i < num_channels; ++i) {
                 status += Mix_FadeOutChannel(i, ms);
             }
         } else if (which < num_channels) {
@@ -1269,7 +1332,7 @@ int Mix_FadeOutChannel(int which, int ms)
             Mix_UnlockAudio();
         }
     }
-    return(status);
+    return status;
 }
 
 /* Halt playing of a particular group of channels */
@@ -1277,12 +1340,12 @@ int Mix_FadeOutGroup(int tag, int ms)
 {
     int i;
     int status = 0;
-    for (i=0; i<num_channels; ++i) {
+    for (i = 0; i < num_channels; ++i) {
         if (mix_channel[i].tag == tag) {
             status += Mix_FadeOutChannel(i,ms);
         }
     }
-    return(status);
+    return status;
 }
 
 Mix_Fading Mix_FadingChannel(int which)
@@ -1304,7 +1367,7 @@ int Mix_Playing(int which)
     if (which == -1) {
         int i;
 
-        for (i=0; i<num_channels; ++i) {
+        for (i = 0; i < num_channels; ++i) {
             if ((mix_channel[i].playing > 0) ||
                 mix_channel[i].looping)
             {
@@ -1318,7 +1381,7 @@ int Mix_Playing(int which)
             ++status;
         }
     }
-    return(status);
+    return status;
 }
 
 /* rcg06072001 Get the chunk associated with a channel. */
@@ -1330,7 +1393,7 @@ Mix_Chunk *Mix_GetChunk(int channel)
         retval = mix_channel[channel].chunk;
     }
 
-    return(retval);
+    return retval;
 }
 
 /* Close the mixer, halting all playing audio */
@@ -1369,7 +1432,7 @@ void Mix_Pause(int which)
     if (which == -1) {
         int i;
 
-        for (i=0; i<num_channels; ++i) {
+        for (i = 0; i < num_channels; ++i) {
             if (Mix_Playing(i)) {
                 mix_channel[i].paused = sdl_ticks;
             }
@@ -1390,17 +1453,19 @@ void Mix_Resume(int which)
     if (which == -1) {
         int i;
 
-        for (i=0; i<num_channels; ++i) {
+        for (i = 0; i < num_channels; ++i) {
             if (Mix_Playing(i)) {
-                if (mix_channel[i].expire > 0)
+                if (mix_channel[i].expire > 0) {
                     mix_channel[i].expire += sdl_ticks - mix_channel[i].paused;
+                }
                 mix_channel[i].paused = 0;
             }
         }
     } else if (which < num_channels) {
         if (Mix_Playing(which)) {
-            if (mix_channel[which].expire > 0)
+            if (mix_channel[which].expire > 0) {
                 mix_channel[which].expire += sdl_ticks - mix_channel[which].paused;
+            }
             mix_channel[which].paused = 0;
         }
     }
@@ -1412,51 +1477,52 @@ int Mix_Paused(int which)
     if (which < 0) {
         int status = 0;
         int i;
-        for(i=0; i < num_channels; ++i) {
+        for (i = 0; i < num_channels; ++i) {
             if (Mix_Playing(i) && mix_channel[i].paused) {
-                ++ status;
+                ++status;
             }
         }
-        return(status);
-    } else if (which < num_channels) {
-        return(Mix_Playing(which) && mix_channel[which].paused != 0);
-    } else {
-        return(0);
+        return status;
     }
+    if (which < num_channels) {
+        return (Mix_Playing(which) && mix_channel[which].paused != 0);
+    }
+    return 0;
 }
 
 /* Change the group of a channel */
 int Mix_GroupChannel(int which, int tag)
 {
-    if (which < 0 || which > num_channels)
-        return(0);
+    if (which < 0 || which > num_channels) {
+        return 0;
+    }
 
     Mix_LockAudio();
     mix_channel[which].tag = tag;
     Mix_UnlockAudio();
-    return(1);
+    return 1;
 }
 
 /* Assign several consecutive channels to a group */
 int Mix_GroupChannels(int from, int to, int tag)
 {
     int status = 0;
-    for(; from <= to; ++ from) {
+    for (; from <= to; ++from) {
         status += Mix_GroupChannel(from, tag);
     }
-    return(status);
+    return status;
 }
 
 /* Finds the first available channel in a group of channels */
 int Mix_GroupAvailable(int tag)
 {
     int i;
-    for(i=0; i < num_channels; i ++) {
-        if (((tag == -1) || (tag == mix_channel[i].tag)) &&
-                            (!Mix_Playing(i)))
+    for (i = 0; i < num_channels; i++) {
+        if ((tag == -1 || tag == mix_channel[i].tag) && !Mix_Playing(i)) {
             return i;
+        }
     }
-    return(-1);
+    return -1;
 }
 
 int Mix_GroupCount(int tag)
@@ -1468,11 +1534,12 @@ int Mix_GroupCount(int tag)
         return num_channels;  /* minor optimization; no need to go through the loop. */
     }
 
-    for(i=0; i < num_channels; i ++) {
-        if (mix_channel[i].tag == tag)
-            ++ count;
+    for (i = 0; i < num_channels; i++) {
+        if (mix_channel[i].tag == tag) {
+            ++count;
+        }
     }
-    return(count);
+    return count;
 }
 
 /* Finds the "oldest" sample playing in a group of channels */
@@ -1481,14 +1548,14 @@ int Mix_GroupOldest(int tag)
     int chan = -1;
     Uint32 mintime = SDL_GetTicks();
     int i;
-    for(i=0; i < num_channels; i ++) {
-        if ((mix_channel[i].tag==tag || tag==-1) && Mix_Playing(i)
+    for (i = 0; i < num_channels; i++) {
+        if ((mix_channel[i].tag == tag || tag == -1) && Mix_Playing(i)
              && mix_channel[i].start_time <= mintime) {
             mintime = mix_channel[i].start_time;
             chan = i;
         }
     }
-    return(chan);
+    return chan;
 }
 
 /* Finds the "most recent" (i.e. last) sample playing in a group of channels */
@@ -1497,14 +1564,14 @@ int Mix_GroupNewer(int tag)
     int chan = -1;
     Uint32 maxtime = 0;
     int i;
-    for(i=0; i < num_channels; i ++) {
-        if ((mix_channel[i].tag==tag || tag==-1) && Mix_Playing(i)
+    for (i = 0; i < num_channels; i++) {
+        if ((mix_channel[i].tag == tag || tag == -1) && Mix_Playing(i)
              && mix_channel[i].start_time >= maxtime) {
             maxtime = mix_channel[i].start_time;
             chan = i;
         }
     }
-    return(chan);
+    return chan;
 }
 
 
@@ -1523,18 +1590,18 @@ static int _Mix_register_effect(effect_info **e, Mix_EffectFunc_t f,
 
     if (!e) {
         Mix_SetError("Internal error");
-        return(0);
+        return 0;
     }
 
     if (f == NULL) {
         Mix_SetError("NULL effect callback");
-        return(0);
+        return 0;
     }
 
-    new_e = SDL_malloc(sizeof (effect_info));
+    new_e = SDL_malloc(sizeof(effect_info));
     if (new_e == NULL) {
         Mix_OutOfMemory();
-        return(0);
+        return 0;
     }
 
     new_e->callback = f;
@@ -1556,7 +1623,7 @@ static int _Mix_register_effect(effect_info **e, Mix_EffectFunc_t f,
         }
     }
 
-    return(1);
+    return 1;
 }
 
 
@@ -1569,7 +1636,7 @@ static int _Mix_remove_effect(int channel, effect_info **e, Mix_EffectFunc_t f)
 
     if (!e) {
         Mix_SetError("Internal error");
-        return(0);
+        return 0;
     }
 
     for (cur = *e; cur != NULL; cur = cur->next) {
@@ -1585,13 +1652,13 @@ static int _Mix_remove_effect(int channel, effect_info **e, Mix_EffectFunc_t f)
             } else {
                 prev->next = next;
             }
-            return(1);
+            return 1;
         }
         prev = cur;
     }
 
     Mix_SetError("No such effect registered");
-    return(0);
+    return 0;
 }
 
 
@@ -1603,7 +1670,7 @@ static int _Mix_remove_all_effects(int channel, effect_info **e)
 
     if (!e) {
         Mix_SetError("Internal error");
-        return(0);
+        return 0;
     }
 
     for (cur = *e; cur != NULL; cur = next) {
@@ -1615,7 +1682,7 @@ static int _Mix_remove_all_effects(int channel, effect_info **e)
     }
     *e = NULL;
 
-    return(1);
+    return 1;
 }
 
 
@@ -1630,7 +1697,7 @@ int _Mix_RegisterEffect_locked(int channel, Mix_EffectFunc_t f,
     } else {
         if ((channel < 0) || (channel >= num_channels)) {
             Mix_SetError("Invalid channel number");
-            return(0);
+            return 0;
         }
         e = &mix_channel[channel].effects;
     }
@@ -1659,7 +1726,7 @@ int _Mix_UnregisterEffect_locked(int channel, Mix_EffectFunc_t f)
     } else {
         if ((channel < 0) || (channel >= num_channels)) {
             Mix_SetError("Invalid channel number");
-            return(0);
+            return 0;
         }
         e = &mix_channel[channel].effects;
     }
@@ -1673,7 +1740,7 @@ int Mix_UnregisterEffect(int channel, Mix_EffectFunc_t f)
     Mix_LockAudio();
     retval = _Mix_UnregisterEffect_locked(channel, f);
     Mix_UnlockAudio();
-    return(retval);
+    return retval;
 }
 
 /* MAKE SURE you hold the audio lock (Mix_LockAudio()) before calling this! */
@@ -1686,7 +1753,7 @@ int _Mix_UnregisterAllEffects_locked(int channel)
     } else {
         if ((channel < 0) || (channel >= num_channels)) {
             Mix_SetError("Invalid channel number");
-            return(0);
+            return 0;
         }
         e = &mix_channel[channel].effects;
     }
@@ -1700,7 +1767,7 @@ int Mix_UnregisterAllEffects(int channel)
     Mix_LockAudio();
     retval = _Mix_UnregisterAllEffects_locked(channel);
     Mix_UnlockAudio();
-    return(retval);
+    return retval;
 }
 
 void Mix_LockAudio(void)
@@ -1723,7 +1790,7 @@ int Mix_MasterVolume(int volume)
         volume = SDL_MIX_MAXVOLUME;
     }
     SDL_AtomicSet(&master_volume, volume);
-    return(prev_volume);
+    return prev_volume;
 }
 
 /* end of mixer.c ... */
